@@ -281,14 +281,14 @@ def PathString(path):
 
         elif 'virtualenv' in __file__:
             # when using pipenv
-            projPath = _PathlibPath(PROJECT_PATH)
+            projPath = _PathlibPath(PROJECT_PATH)  # default is '.'
 
             if str(path).startswith('/'):
-                if path.startswith(str(projPath)):
+                if str(path).startswith(str(projPath)):
                     # path already starts with project path
                     ret = path
                 else:
-                    path = path[1:]
+                    path = str(path)[1:]
                     ret = projPath / path
             else:
                 ret = projPath / path
@@ -309,16 +309,18 @@ class File:
 class FormFile(File):
     def __init__(self, requestFilesKey):
         self._key = requestFilesKey
-        self._name = secure_filename(
-            str(uuid.uuid4()) + request.files[self._key].filename  # adds uuid prefix to prevent colisions
-        )
+        self._name = secure_filename(  # prevents dangerous characters
+            '{}_{}'.format(
+                uuid.uuid4(),
+                request.files[self._key].filename
+            ))  # adds uuid prefix to prevent colisions
         super().__init__(self._key)
 
     def SaveTo(self, newPath):
         if _PathlibPath(newPath).is_dir():
             newPath = _PathlibPath(newPath) / self._name
 
-        request.files[self._key].save(PathString(newPath))
+        request.files[self._key].save(str(newPath))
         return SystemFile(newPath)
 
     @property
